@@ -1,9 +1,10 @@
 package Test::Class::Moose;
-$Test::Class::Moose::VERSION = '0.43';
+$Test::Class::Moose::VERSION = '0.50';
 # ABSTRACT: Test::Class + Moose
 
 use 5.10.0;
 use Moose 2.0000;
+use MooseX::ClassAttribute;
 use Carp;
 use List::Util qw(shuffle);
 use List::MoreUtils qw(uniq);
@@ -16,43 +17,101 @@ use Test::Class::Moose::Config;
 use Test::Class::Moose::Report;
 use Test::Class::Moose::Report::Class;
 use Test::Class::Moose::Report::Method;
-use Test::Class::Moose::TagRegistry;
+use Test::Class::Moose::AttributeRegistry;
 
-our $NO_CAN_HAZ_ATTRIBUTES;
-BEGIN {
-    eval "use Sub::Attribute";
-    unless ( $NO_CAN_HAZ_ATTRIBUTES = $@ ) {
-        eval <<'DECLARE_ATTRIBUTE';
-        sub Tags : ATTR_SUB {
-            my ( $class, $symbol, undef, undef, $data, undef, $file, $line ) = @_;
+sub __create_attributes {
+    return <<'DECLARE_ATTRIBUTES';
+    sub Tags : ATTR_SUB {
+        my ( $class, $symbol, undef, undef, $data, undef, $file, $line ) = @_;
 
-            my @tags;
-            if ($data) {
-                $data =~ s/^\s+//g;
-                @tags = split /\s+/, $data;
-            }
+        my @tags;
+        if ($data) {
+            $data =~ s/^\s+//g;
+            @tags = split /\s+/, $data;
+        }
 
-            if ( $symbol eq 'ANON' ) {
-                die "Cannot tag anonymous subs at file $file, line $line\n";
-            }
+        if ( $symbol eq 'ANON' ) {
+            die "Cannot tag anonymous subs at file $file, line $line\n";
+        }
 
-            my $method = *{ $symbol }{ NAME };
+        my $method = *{$symbol}{NAME};
 
-            {           # block for localising $@
-                local $@;
+        {    # block for localising $@
+            local $@;
 
-                Test::Class::Moose::TagRegistry->add(
-                    $class,
-                    $method,
-                    \@tags,
-                );
-                if ( $@ ) {
-                    croak "Error in adding tags: $@";
-                }
+            Test::Class::Moose::AttributeRegistry->add_tags(
+                $class,
+                $method,
+                \@tags,
+            );
+            if ($@) {
+                croak "Error in adding tags: $@";
             }
         }
-DECLARE_ATTRIBUTE
-        $NO_CAN_HAZ_ATTRIBUTES = $@;
+    }
+
+    sub Test : ATTR_SUB {
+        my ( $class, $symbol, undef, undef, undef, undef, $file, $line ) = @_;
+
+        if ( $symbol eq 'ANON' ) {
+            die "Cannot add plans to anonymous subs at file $file, line $line\n";
+        }
+
+        my $method = *{$symbol}{NAME};
+        if ( $method =~ /^test_(?:startup|setup|teardown|shutdown)$/ ) {
+            croak("Test control method '$method' may not have a Test attribute");
+        }
+
+        Test::Class::Moose::AttributeRegistry->add_plan(
+            $class,
+            $method,
+            1,
+        );
+        $class->meta->add_before_method_modifier($method, sub {
+            my $test = shift;
+            $test->test_report->plan(1);
+        });
+    }
+
+    sub Tests : ATTR_SUB {
+        my ( $class, $symbol, undef, undef, $data, undef, $file, $line ) = @_;
+
+        if ( $symbol eq 'ANON' ) {
+            die "Cannot add plans to anonymous subs at file $file, line $line\n";
+        }
+
+        my $method = *{$symbol}{NAME};
+        if ( $method =~ /^test_(?:startup|setup|teardown|shutdown)$/ ) {
+            croak("Test control method '$method' may not have a Test attribute");
+        }
+
+        Test::Class::Moose::AttributeRegistry->add_plan(
+            $class,
+            $method,
+            $data,
+        );
+        if ( defined $data ) {
+            $class->meta->add_before_method_modifier($method, sub {
+                my $test = shift;
+                $test->test_report->plan($data);
+            });
+        }
+    }
+DECLARE_ATTRIBUTES
+}
+
+BEGIN {
+    class_has '__attributes_unavailable' => (
+        is      => 'rw',
+        isa     => 'Str',
+        default => '',
+        writer  => '_set___attributes_unavailable',
+    );
+    eval "use Sub::Attribute";
+    __PACKAGE__->_set___attributes_unavailable($@);
+    unless (__PACKAGE__->__attributes_unavailable) {
+        eval __PACKAGE__->__create_attributes;
+        __PACKAGE__->_set___attributes_unavailable($@);
     }
 }
 
@@ -89,7 +148,7 @@ use Moose;
 use Test::Most;
 END
 
-    unless ($NO_CAN_HAZ_ATTRIBUTES) {
+    unless ($class->__attributes_unavailable) {
         $preamble .= "use Sub::Attribute;\n";
     }
     eval $preamble;
@@ -119,9 +178,10 @@ sub BUILD {
 
     my $config = $self->test_configuration;
     if ( ( $config->include_tags or $config->exclude_tags )
-        and $NO_CAN_HAZ_ATTRIBUTES )
+        and $self->__attributes_unavailable )
     {
-        carp("Attributes not available: $NO_CAN_HAZ_ATTRIBUTES");
+        my $reason = $self->__attributes_unavailable;
+        carp("Attributes not available: $reason");
         $config->clear_include_tags;
         $config->clear_exclude_tags;
     }
@@ -168,8 +228,7 @@ my $RUN_TEST_CONTROL_METHOD = sub {
     return $success;
 };
 
-my $RUN_TEST_METHOD = sub {
-    local *__ANON__ = 'ANON_RUN_TEST_METHOD';
+sub _tcm_run_test_method {
     my ( $self, $test_instance, $test_method, $report_class ) = @_;
 
     my $test_class = $test_instance->test_class;
@@ -218,20 +277,6 @@ my $RUN_TEST_METHOD = sub {
         },
     );
 
-    # The set_color() method from Test::Formatter::Color is just ugly.
-    if ( $config->running_in_parallel ) {
-
-        # we're running under parallel testing, so rather than having
-        # the code look like it's stalled, we'll output a dot for
-        # every test method.
-        my $color = ( $builder->details )[-1]{ok} ? 'green' : 'red';
-        $config->_color->set_color(
-            sub { print STDERR shift, '.' },
-            $color,
-        );
-        $config->_color->set_color( sub { print STDERR shift }, 'reset' );
-    }
-
     $test_instance->$RUN_TEST_CONTROL_METHOD(
         'test_teardown',
         $report
@@ -243,7 +288,7 @@ my $RUN_TEST_METHOD = sub {
         }
     }
     return $report;
-};
+}
 
 my $RUN_TEST_CLASS = sub {
     local *__ANON__ = 'ANON_RUN_TEST_CLASS';
@@ -298,7 +343,7 @@ my $RUN_TEST_CLASS = sub {
 
         # run test methods
         foreach my $test_method (@test_methods) {
-            my $report_method = $self->$RUN_TEST_METHOD(
+            my $report_method = $self->_tcm_run_test_method(
                 $test_instance,
                 $test_method,
                 $report_class,
@@ -375,9 +420,8 @@ my $FILTER_BY_TAG = sub {
     if ( my $include = $self->test_configuration->include_tags ) {
         my @new_method_list;
         foreach my $method (@filtered_methods) {
-            my $subref = $class->can($method);
             foreach my $tag (@$include) {
-                if (Test::Class::Moose::TagRegistry->method_has_tag(
+                if (Test::Class::Moose::AttributeRegistry->method_has_tag(
                         $class, $method, $tag
                     )
                   )
@@ -393,7 +437,7 @@ my $FILTER_BY_TAG = sub {
         foreach my $method (@filtered_methods) {
             foreach my $tag (@$exclude) {
                 if (
-                    Test::Class::Moose::TagRegistry->method_has_tag(
+                    Test::Class::Moose::AttributeRegistry->method_has_tag(
                         $class, $method, $tag
                     )
                   )
@@ -415,8 +459,13 @@ sub test_methods {
 
         # attributes cannot be test methods
         next if $method->isa('Moose::Meta::Method::Accessor');
+
+        my $class = ref $self;
         my $name = $method->name;
-        next unless $name =~ /^test_/;
+        next
+          unless $name =~ /^test_/
+          || Test::Class::Moose::AttributeRegistry->has_test_attribute(
+            $class, $name );
 
         # don't use anything defined in this package
         next if __PACKAGE__->can($name);
@@ -459,7 +508,7 @@ Test::Class::Moose - Test::Class + Moose
 
 =head1 VERSION
 
-version 0.43
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -519,6 +568,22 @@ not are not test methods.
     # but you can, of course, call it like normal
  }
 
+As of 0.50, if you have L<Sub::Attribute> installed, you may specify C<Test>
+and C<Test> methods, just like in L<Test::Class> and the method will
+automatically be a test method, even if does not start with C<test_>:
+
+    sub this_is_a_test : Test {
+        pass 'we have a single test';
+    }
+
+    sub another_test_method : Tests { # like "no_plan"
+        # a bunch of tests
+    }
+
+    sub yet_another_test_method : Tests(7) { # sets plan to 7 tests
+        ...
+    }
+
 =head2 Plans
 
 No plans needed. The test suite declares a plan of the number of test classes.
@@ -535,6 +600,13 @@ If you prefer, you can declare a plan in a test method:
         ...
     }
 
+Or with a C<Tests> attribute:
+
+    sub test_something : Tests(3) {
+        my $test = shift;
+        ...
+    }
+
 You may call C<plan()> multiple times for a given test method. Each call to
 C<plan()> will add that number of tests to the plan.  For example, with a
 method modifier:
@@ -840,6 +912,62 @@ If you wish to skip an individual method, do so in the C<test_setup> method.
         }
     }
 
+=head2 The "Tests" and "Test" Attributes
+
+If you're comfortable with L<Test::Class>, know test methods methods are
+declared in L<Test::Class> with C<Test> (for a method with a single test) or
+C<Tests>, for a method with multiple tests. This also works for
+C<Test::Class::Moose>. Test methods declared this way do not need to start
+with C<test_>.
+
+    sub something_we_want_to_check : Test {
+        # this method may have only one test
+    }
+
+    sub something_else_to_check : Tests {
+        # this method may have multiple tests
+    }
+
+    sub another_test_method : Tests(3) {
+        # this method must have exactly 3 tests
+    }
+
+If a test method overrides a parent test method and calls it, their plans will
+be added together:
+
+    package TestsFor::Parent;
+
+    use Test::Class::Moose;
+
+    sub some_test : Tests(3) {
+        # three tests
+    }
+
+And later:
+
+    package TestsFor::Child;
+
+    use Test::Class::Moose extends => 'TestsFor::Parent';
+
+    sub some_test : Tests(2) {
+        my $test = shift;
+        $test->next::method;
+        # 2 tests here
+    }
+
+In the above example, C<TestsFor::Parent::some_test> will run three tests, but
+C<TestsFor::Child::some_test> will run I<five> tests (two tests, plus the
+three from the parent).
+
+Note that if a plan is explicitly declared, any modifiers or overriding
+methods calling the original method will also have to assert the number of
+tests to ensure the plan is correct. The above C<TestsFor::Parent> and
+C<TestsFor::Child> code would fail if the child's C<some_test> method
+attribute was C<Tests> without the number of tests asserted.
+
+Do not use C<Test> or C<Tests> with test control methods becase you don't run
+tests in those.
+
 =head2 Tagging Methods
 
 Sometimes you want to be able to assign metadata to help you better manage
@@ -895,7 +1023,8 @@ provide your own schedule, in which case you can do anything you want).
 
 As a general rule, methods beginning with C</^test_/> are reserved for
 L<Test::Class::Moose>. This makes it easier to remember what you can and
-cannot override.
+cannot override. However, any test with C<Test> or C<Tests> are test methods
+regardless of their names.
 
 =head2 C<test_configuration>
 
