@@ -1,11 +1,11 @@
 package Test::Class::Moose::Report::Method;
-$Test::Class::Moose::Report::Method::VERSION = '0.43';
+$Test::Class::Moose::Report::Method::VERSION = '0.50';
 # ABSTRACT: Reporting on test methods
 
 use Moose;
 use Carp;
 use namespace::autoclean;
-use Test::Class::Moose::TagRegistry;
+use Test::Class::Moose::AttributeRegistry;
 
 with qw(
   Test::Class::Moose::Role::Reporting
@@ -51,7 +51,7 @@ sub has_tag {
     croak("has_tag(\$tag) requires a tag name") unless defined $tag;
     my $report_class = $self->report_class->name;
     my $method       = $self->name;
-    return Test::Class::Moose::TagRegistry->method_has_tag( $report_class, $method, $tag );
+    return Test::Class::Moose::AttributeRegistry->method_has_tag( $report_class, $method, $tag );
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -70,7 +70,7 @@ Test::Class::Moose::Report::Method - Reporting on test methods
 
 =head1 VERSION
 
-version 0.43
+version 0.50
 
 =head1 DESCRIPTION
 
