@@ -1,75 +1,40 @@
 package Test::Class::Moose::Role;
-$Test::Class::Moose::Role::VERSION = '0.43';
+$Test::Class::Moose::Role::VERSION = '0.50';
 # ABSTRACT: Test::Class::Moose for roles
 
 use 5.10.0;
-use Carp qw/carp croak cluck/;
+use Carp;
 
-use Test::Class::Moose::TagRegistry;
+use Test::Class::Moose::AttributeRegistry;
 
-our $NO_CAN_HAZ_ATTRIBUTES;
 BEGIN {
+    require Test::Class::Moose;
     eval "use Sub::Attribute";
-    unless($NO_CAN_HAZ_ATTRIBUTES = $@){
-        eval <<'DECLARE_ATTRIBUTE';
-        sub Tags : ATTR_SUB {
-            my ( $class, $symbol, undef, undef, $data, undef, $file, $line ) = @_;
-
-            my @tags;
-            if ($data) {
-                $data =~ s/^\s+//g;
-                @tags = split /\s+/, $data;
-            }
-
-            if ( $symbol eq 'ANON' ) {
-                die "Cannot tag anonymous subs at file $file, line $line\n";
-            }
-
-            my $method = *{ $symbol }{ NAME };
-
-            {           # block for localising $@
-                local $@;
-
-                Test::Class::Moose::TagRegistry->add(
-                    $class,
-                    $method,
-                    \@tags,
-                );
-                if ( $@ ) {
-                    croak "Error in adding tags: $@";
-                }
-            }
-        }
-DECLARE_ATTRIBUTE
-        $NO_CAN_HAZ_ATTRIBUTES = $@;
+    unless ( Test::Class::Moose->__attributes_unavailable ) {
+        eval Test::Class::Moose->__create_attributes;
     }
 }
 
-
 sub import {
     my ( $class, %arg_for ) = @_;
     my $caller = caller;
 
-
     my $preamble = <<"END";
 package $caller;
 use Moose::Role;
 use Test::Most;
-
-use strict;
-use warnings;
-
-use Carp;
-use Data::Dumper;
 END
 
-    unless ($NO_CAN_HAZ_ATTRIBUTES) {
+    unless ( Test::Class::Moose->__attributes_unavailable ) {
         $preamble .= "use Sub::Attribute;\n";
     }
     eval $preamble;
-    unless ($NO_CAN_HAZ_ATTRIBUTES) {
+    croak($@) if $@;
+    unless ( Test::Class::Moose->__attributes_unavailable ) {
         no strict "refs";
-        *{"$caller\::Tags"} = \&Tags;
+        *{"$caller\::Tags"}  = \&Tags;
+        *{"$caller\::Test"}  = \&Test;
+        *{"$caller\::Tests"} = \&Tests;
     }
 }
 
@@ -87,7 +52,7 @@ Test::Class::Moose::Role - Test::Class::Moose for roles
 
 =head1 VERSION
 
-version 0.43
+version 0.50
 
 =head1 DESCRIPTION
 
