@@ -1,14 +1,20 @@
 package Test::Class::Moose::Role::Parallel;
-$Test::Class::Moose::Role::Parallel::VERSION = '0.43';
+$Test::Class::Moose::Role::Parallel::VERSION = '0.50';
 # ABSTRACT: run tests in parallel (highly experimental)
 
 use Moose::Role;
 use Parallel::ForkManager;
 use Test::Builder;
 use TAP::Stream;
-use Test::Class::Moose::TagRegistry;
+use Test::Class::Moose::AttributeRegistry;
 use Carp;
 
+has 'color_output' => (
+    is      => 'ro',
+    isa     => 'Bool',
+    default => 1,
+);
+
 my $run_job = sub {
     my ( $self, $orig ) = @_;
 
@@ -81,7 +87,7 @@ around 'runtests' => sub {
     print STDERR "\n";
 
     # this is where we print the TAP results
-    print $test_builder_output $stream->tap_to_string;
+    print $test_builder_output $stream->to_string;
 };
 
 around 'test_classes' => sub {
@@ -109,6 +115,32 @@ around 'test_methods' => sub {
     return grep { $methods_for_jobs->{$_} } @test_methods;
 };
 
+after '_tcm_run_test_method' => sub {
+    my $self    = shift;
+    my $config  = $self->test_configuration;
+    my $builder = $config->builder;
+
+    # we're running under parallel testing, so rather than having
+    # the code look like it's stalled, we'll output a dot for
+    # every test method.
+    my ( $color, $text )
+      = ( $builder->details )[-1]{ok}
+      ? ( 'green', '.' )
+      : ( 'red', 'X' );
+
+    # The set_color() method from Test::Formatter::Color is just ugly.
+    if ( $self->color_output ) {
+        $config->_color->set_color(
+            sub { print STDERR shift, $text },
+            $color,
+        );
+        $config->_color->set_color( sub { print STDERR shift }, 'reset' );
+    }
+    else {
+        print STDERR $text;
+    }
+};
+
 sub schedule {
     my $self   = shift;
     my $config = $self->test_configuration;
@@ -120,7 +152,7 @@ sub schedule {
     foreach my $test_class ( $self->test_classes ) {
         my $test_instance = $test_class->new( $config->args );
         METHOD: foreach my $method ( $test_instance->test_methods ) {
-            if ( Test::Class::Moose::TagRegistry->method_has_tag( $test_class, $method, 'noparallel' ) ) {
+            if ( Test::Class::Moose::AttributeRegistry->method_has_tag( $test_class, $method, 'noparallel' ) ) {
                 $sequential{$test_class}{$method} = 1;
                 next METHOD;
             }
@@ -149,7 +181,7 @@ Test::Class::Moose::Role::Parallel - run tests in parallel (highly experimental)
 
 =head1 VERSION
 
-version 0.43
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -330,11 +362,11 @@ Or it could be that some tests run in parallel with some tests, but not
 others. Again, your schedule needs to be written to take that into account.
 
 To manage this information better, if you can use tags, you'll find that
-C<Test::Class::Moose::TagRegistry> can help:
+C<Test::Class::Moose::AttributeRegistry> can help:
 
-    use aliased 'Test::Class::Moose::TagRegistry';
+    use aliased 'Test::Class::Moose::AttributeRegistry';
 
-    if ( TagRegistry->method_has_tag( $class, $method, $tag ) ) {
+    if ( AttributeRegistry->method_has_tag( $class, $method, $tag ) ) {
 
         # put the method in the appropriate job
     }
